@@ -2,7 +2,7 @@
 //!
 //! [![Crates.io](https://img.shields.io/crates/v/pso_rs?style=for-the-badge)](https://crates.io/crates/pso-rs)
 //! [![docs.rs](https://img.shields.io/docsrs/pso-rs?style=for-the-badge)](https://docs.rs/pso-rs/latest/pso_rs/)
-//! [![GitHub](https://img.shields.io/github/license/czonios/pso-rs)](https://github.com/czonios/pso-rs/blob/master/LICENSE?style=for-the-badge)
+//! [![GitHub](https://img.shields.io/github/license/czonios/pso-rs?style=for-the-badge)](https://github.com/czonios/pso-rs/blob/master/LICENSE)
 //!
 //! It uses the [`rand`](https://crates.io/crates/rand) crate for random initialization, and the [`rayon`](https://crates.io/crates/rayon) crate for parallel objective function computation. It also has a nice progress bar curtesy of the [`indicatif`](https://crates.io/crates/indicatif) crate.
 //!
@@ -12,12 +12,16 @@
 //! # Examples
 //!
 //! ```rust
-//! use pso_rs::model::*;
+//! use pso_rs::*;
 //!
 //! // define objective function (Rosenbrock)
-//! fn objective_function(p: &Particle, _flat_dim: usize, _dimensions: &Vec<usize>) -> f64 {
+//! fn objective_function(p: &Particle,
+//!                 _flat_dim: usize,
+//!                 _dimensions: &Vec<usize>)
+//!     -> f64 {
 //!     // x = p[0], y = p[1]
-//!     (1.0-p[0]).powf(2.0) + 100.0 * ((p[1]-p[0]).powf(2.0)).powf(2.0)
+//!     (1.0-p[0]).powf(2.0) + 100.0
+//!         * ((p[1]-p[0]).powf(2.0)).powf(2.0)
 //! }
 //!
 //! // define a termination condition
@@ -26,13 +30,20 @@
 //! }
 //!
 //! let config = Config {
-//!     dimensions: vec![2],    // dimension shape of each particle
-//!     bounds: (-5.0, 10.0),   // problem bounds
-//!     t_max: 10000,           // maximum no. of objective function computations
-//!     ..Config::default()     // leave the rest of the params as default
+//!     // dimension shape of each particle
+//!     dimensions: vec![2],
+//!     // problem bounds in each dimension
+//!     bounds: (-5.0, 10.0),
+//!     // maximum no. of objective function computations
+//!     t_max: 10000,
+//!     // leave the rest of the params as default
+//!     ..Config::default()
 //! };
 //!
-//! let pso = pso_rs::run(config, objective_function, terminate).unwrap();
+//! let pso = pso_rs::run(config,
+//!                 objective_function,
+//!                 Some(terminate)).unwrap();
+//!     
 //! let model = pso.model;
 //! println!("Model: {:?} ", model.get_f_best());
 //! ```
@@ -45,18 +56,11 @@
 //! If you want, you can also create a custom `reshape` function, like this one for molecule clusters below:
 //!
 //! ```rust
-//! use pso_rs::model::*;
+//! use pso_rs::*;
 //!
-//! let config = Config {
-//!     dimensions: vec![20, 3],
-//!     bounds: (-2.5, 2.5),
-//!     t_max: 1,
-//!     ..Config::default()
-//! };
-//!
-//! let pso = pso_rs::run(config, objective_function, |_| true).unwrap();
-//!
-//! fn reshape(particle: &Particle, particle_dims: &Vec<usize>) -> Vec<Vec<f64>> {
+//! fn reshape(particle: &Particle,
+//!         particle_dims: &Vec<usize>)
+//!     -> Vec<Vec<f64>> {
 //!     let mut reshaped_cluster = vec![];
 //!     let mut i = 0;
 //!     for _ in 0..particle_dims[0] {
@@ -70,24 +74,38 @@
 //!     reshaped_cluster
 //! }
 //!
-//! // somewhere in main(), after running PSO as in the example:
-//! println!(
-//!     "Best found minimizer: {:#?} ",
-//!     reshape(&pso.model.get_x_best(), &pso.model.config.dimensions)
-//! );
-//!
 //! // used in the objective function
-//! fn objective_function(p: &Particle, flat_dim: usize, dimensions: &Vec<usize>) -> f64 {
-//!      let reshaped_particle = reshape(p, dimensions);
+//! fn objective_function(p: &Particle,
+//!                 _flat_dim: usize,
+//!                 dimensions: &Vec<usize>)
+//!     -> f64 {
+//!     let _reshaped_particle = reshape(p, dimensions);
 //!     /* Do stuff */
 //!     0.0
 //! }
+//!
+//! let config = Config {
+//!     dimensions: vec![20, 3],
+//!     bounds: (-2.5, 2.5),
+//!     t_max: 1,
+//!     ..Config::default()
+//! };
+//! let pso = pso_rs::run(config,
+//!                     objective_function,
+//!                     None).unwrap();
+//!
+//! // somewhere in main(), after running PSO as in the example:
+//! println!(
+//!     "Best found minimizer: {:#?} ",
+//!     reshape(&pso.model.get_x_best(),
+//!         &pso.model.config.dimensions)
+//! );
 //! ```
 
 pub mod model;
 mod pso;
 
-pub use model::{Config, NeighborhoodType, Particle, Population};
+pub use model::*;
 
 use model::Model;
 use pso::PSO;
@@ -101,11 +119,15 @@ use std::error::Error;
 pub fn run(
     config: Config,
     obj_f: fn(&Particle, usize, &Vec<usize>) -> f64,
-    terminate_f: fn(f64) -> bool,
+    terminate_f: Option<fn(f64) -> bool>,
 ) -> Result<PSO, Box<dyn Error>> {
     let model = Model::new(config, obj_f);
     let mut pso = PSO::new(model);
-    pso.run(terminate_f);
+    let term_condition = match terminate_f {
+        Some(terminate_f) => terminate_f,
+        None => |_| false,
+    };
+    pso.run(term_condition);
     Ok(pso)
 }
 
